# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['urbanity']

package_data = \
{'': ['*'],
 'urbanity': ['lcz_data/*',
              'map_data/*',
              'overture_data/*',
              'svi_data/num_to_class.json',
              'svi_data/num_to_class.json',
              'svi_data/svi_data.json',
              'svi_data/svi_data.json']}

install_requires = \
['charset-normalizer==2.1.1',
 'geopandas>=1.0.1,<2.0.0',
 'h5py>=3.11.0,<4.0.0',
 'ipykernel==6.16.2',
 'ipyleaflet==0.17.2',
 'ipywidgets==8.0.2',
 'mercantile>=1.2.1,<2.0.0',
 'networkit==10.1',
 'networkx==2.8.6',
 'numpy==1.26.4',
 'overturemaps>=0.8.0,<0.9.0',
 'pandas>=2.2.2,<3.0.0',
 'protobuf==3.20.0',
 'pydeck>=0.9.1,<0.10.0',
 'pyrobuf==0.9.3',
 'pyrosm==0.6.2',
 'rasterio>=1.3.8,<2.0.0']

setup_kwargs = {
    'name': 'urbanity',
    'version': '0.4.3',
    'description': '',
    'long_description': None,
    'author': 'winstonyym',
    'author_email': 'winstonyym@u.nus.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
